@@ -243,10 +243,10 @@ impl AssignFolder {
                                     .clone()
                                     .make_member(quote_ident!("slice"))
                                     .as_callee(),
-                                args: vec![Lit::Num(Number {
+                                args: vec![Number {
                                     value: i as f64,
                                     span: dot3_token,
-                                })
+                                }
                                 .as_arg()],
                                 type_args: Default::default(),
                             }))),
@@ -1194,7 +1194,7 @@ fn can_be_null(e: &Expr) -> bool {
         Expr::TsAs(TsAsExpr { ref expr, .. })
         | Expr::TsTypeAssertion(TsTypeAssertion { ref expr, .. })
         | Expr::TsConstAssertion(TsConstAssertion { ref expr, .. })
-        | Expr::TsInstantiation(TsExprWithTypeArgs { ref expr, .. }) => can_be_null(expr),
+        | Expr::TsInstantiation(TsInstantiation { ref expr, .. }) => can_be_null(expr),
 
         Expr::Invalid(..) => unreachable!(),
     }
